from typing import List

from continuedev.core.context import (
    ContextProvider,
    ContextItem,
    ContextItemDescription,
    ContextItemId,
)

from atlassian import Confluence
from markdownify import markdownify as md


class ConfluenceContextProvider(ContextProvider):
    title = "confluence"
    display_title = "Confluence Pages"
    description = "Reference Confluence pages"
    dynamic = True
    requires_query = True

    server: str
    username: str
    token: str

    CONFLUENCE_CONTEXT_ITEM_ID = "confluence_page"

    @property
    def BASE_CONTEXT_ITEM(self):
        return ContextItem(
            content="",
            description=ContextItemDescription(
                name="Confluence Page",
                description="Enter the id of the Confluence page",
                id=ContextItemId(
                    provider_title=self.title, item_id=self.CONFLUENCE_CONTEXT_ITEM_ID
                ),
            ),
        )

    async def provide_context_items(self, workspace_dir: str) -> List[ContextItem]:
        return [self.BASE_CONTEXT_ITEM]

    async def get_item(self, id: ContextItemId, query: str) -> ContextItem:
        if not id.provider_title == self.title:
            raise Exception("Invalid provider title for item")
        page_id = query.lstrip(self.title + " ").strip()
        if page_id is None or page_id == "":
            return None
        confluence = Confluence(
            url=self.server, username=self.username, password=self.token, cloud=True
        )
        page = confluence.get_page_by_id(
            page_id,
            expand="space,body.view",
            status=None,
            version=None,
        )
        ctx_item = self.BASE_CONTEXT_ITEM.copy()
        ctx_item.description.name = f"Page {page['id']}"
        ctx_item.description.description = f"{page['space']['name']} / {page['title']}"
        ctx_item.description.id.item_id = page["id"]
        ctx_item.content = md(page["body"]["view"]["value"])
        return ctx_item
