from typing import List

from continuedev.core.context import (
    ContextItem,
    ContextItemDescription,
    ContextItemId,
    ContextProvider,
)

from gitlab import Gitlab


class GitLabContextProvider(ContextProvider):
    title = "gitlab"
    display_title = "GitLab Issues"
    description = "Reference GitLab issues"
    dynamic = False

    server: str
    token: str

    async def provide_context_items(self, workspace_dir: str) -> List[ContextItem]:
        gl = Gitlab(url=self.server, private_token=self.token)
        issues = gl.issues.list(state="opened", scope="all", per_page=100)
        return [
            ContextItem(
                content=issue.description,
                description=ContextItemDescription(
                    name=f"Issue #{issue.project_id}.{issue.iid}",
                    description=issue.title,
                    id=ContextItemId(provider_title=self.title, item_id=str(issue.id)),
                ),
            )
            for issue in issues
        ]
