from typing import List

from continuedev.core.context import (
    ContextProvider,
    ContextItem,
    ContextItemDescription,
    ContextItemId,
)

from atlassian import Jira


class JIRAContextProvider(ContextProvider):
    title = "jira"
    display_title = "Jira Issues"
    description = "Reference Jira issues"
    dynamic = True
    requires_query = True

    server: str
    username: str
    token: str

    JIRA_CONTEXT_ITEM_ID = "jira_issue"

    @property
    def BASE_CONTEXT_ITEM(self):
        return ContextItem(
            content="",
            description=ContextItemDescription(
                name="Jira Issue",
                description="Enter the key of the Jira issue",
                id=ContextItemId(
                    provider_title=self.title, item_id=self.JIRA_CONTEXT_ITEM_ID
                ),
            ),
        )

    async def provide_context_items(self, workspace_dir: str) -> List[ContextItem]:
        return [self.BASE_CONTEXT_ITEM]

    async def get_item(self, id: ContextItemId, query: str) -> ContextItem:
        if not id.provider_title == self.title:
            raise Exception("Invalid provider title for item")
        issue_key = query.lstrip(self.title + " ").strip()
        if issue_key is None or issue_key == "":
            return None
        jira = Jira(
            url=self.server, username=self.username, password=self.token, cloud=True
        )
        issue = jira.issue(issue_key)
        ctx_item = self.BASE_CONTEXT_ITEM.copy()
        ctx_item.description.name = issue["key"]
        ctx_item.description.description = issue["fields"]["summary"]
        ctx_item.description.id.item_id = issue["id"]
        ctx_item.content = issue["fields"]["description"]
        return ctx_item
